@@ -7,7 +7,7 @@ from requests import exceptions
 import six
 
 from .util import ApiXmlHelper
-from .exceptions import KempTechApiException
+from .exceptions import KempTechApiException, CommandNotAvailableException
 
 
 requests.packages.urllib3.disable_warnings()
@@ -149,7 +149,7 @@ class LoadMaster(HttpClient):
 
     @property
     def endpoint(self):
-        return "https://{user}:{pw}@{ip}/access/".format(user=self.username,
+        return "https://{user}:{pw}@{ip}/access".format(user=self.username,
                                                          pw=self.password,
                                                          ip=self.ip_address)
 
@@ -190,24 +190,44 @@ class LoadMaster(HttpClient):
             raise KempTechApiException(response.text)
 
     def stats(self):
-        response = self._get('stats')
+        response = self._get('/stats')
         if ApiXmlHelper.is_successful(response):
             return ApiXmlHelper.parse_to_dict(response)
         else:
             raise KempTechApiException(ApiXmlHelper.get_error_msg(response))
 
     def update_firmware(self, file):
-        response = self._post('installpatch', file)
+        response = self._post('/installpatch', file)
         return ApiXmlHelper.is_successful(response)
 
     def shutdown(self):
-        response = self._get('shutdown')
+        response = self._get('/shutdown')
         return ApiXmlHelper.is_successful(response)
 
     def reboot(self):
-        response = self._get('reboot')
+        response = self._get('/reboot')
         return ApiXmlHelper.is_successful(response)
 
     def get_sdn_controller(self):
-        response = self._get('getsdncontroller')
-        return ApiXmlHelper.is_successful(response)
+        response = self._get('/getsdncontroller')
+        if ApiXmlHelper.is_successful(response):
+            return ApiXmlHelper.parse_to_dict(response)
+        else:
+            raise KempTechApiException(ApiXmlHelper.get_error_msg(response))
+
+    def get_license_info(self):
+        try:
+            response = self._get('360/licenseinfo')
+            if ApiXmlHelper.is_successful(response):
+                return ApiXmlHelper.parse_to_dict(response)
+            else:
+                raise KempTechApiException(ApiXmlHelper.get_error_msg(response))
+        except KempTechApiException:
+            raise CommandNotAvailableException('/access360/licenseinfo')
+
+    def list_addons(self):
+        response = self._get('/listaddon')
+        if ApiXmlHelper.is_successful(response):
+            return ApiXmlHelper.parse_to_dict(response)
+        else:
+            raise KempTechApiException(ApiXmlHelper.get_error_msg(response))
